@@ -7,9 +7,10 @@
 #'     classical tabular format. URLs must begin with \kbd{http://},
 #'     \kbd{https://}, \kbd{ftp://}, or \kbd{ftps://}. JSON files must have
 #'     \code{\{} as their first non-whitespace character. Compressed (gzip or
-#'     bzip2) biom files are also supported.
+#'     bzip2) BIOM files are also supported. NOTE: to read HDF5 formatted BIOM
+#'     files, the BioConductor R package \code{rhdf5} must be installed.
 #' @param tree  The default value of \code{auto} will read the tree from the 
-#'     biom file specified in \code{src}, if present. The value \code{TRUE} 
+#'     BIOM file specified in \code{src}, if present. The value \code{TRUE} 
 #'     will do the same, but will generate an error message if a tree is not 
 #'     present. Setting \code{tree=FALSE} will return a \code{BIOM} object 
 #'     without any tree data. You may also provide a file path, URL, or Newick
@@ -51,7 +52,7 @@
 #' @examples
 #'     library(rbiom)
 #'
-#'     infile <- system.file("extdata", "hmp50.biom", package = "rbiom")
+#'     infile <- system.file("extdata", "hmp50.bz2", package = "rbiom")
 #'     biom <- read.biom(infile)
 #'
 #'     summary(biom)
@@ -137,12 +138,27 @@ read.biom <- function (src, tree='auto', prune=FALSE) {
   # Process the file according to its internal format
   #--------------------------------------------------------------
   
-  if (rhdf5::H5Fis_hdf5(fp)) {
+  if (identical(as.numeric(readBin(fp, "raw", 4)), c(137, 72, 68, 70))) {
     
     #-=-=-=-=-=-=-=-=-=-#
     # HDF5 file format  #
     #-=-=-=-=-=-=-=-=-=-#
     
+    if (!requireNamespace("rhdf5", quietly = TRUE)) {
+      stop(simpleError(paste0(
+        "\n",
+        "Error: rbiom requires the R package 'rhdf5' to be installed\n",
+        "in order to read and write HDF5 formatted BIOM files.\n\n",
+        "Please run the following commands to install 'rhdf5':\n",
+        "   install.packages('BiocManager')\n",
+        "   BiocManager::install('rhdf5')\n\n" )))
+    }
+    
+    if (!rhdf5::H5Fis_hdf5(fp)) {
+      stop(simpleError("HDF5 file not recognized by rhdf5."))
+    }
+    
+    
     hdf5      <- PB.HDF5.ReadHDF5(fp)
     counts    <- PB.HDF5.Counts(hdf5)
     sequences <- PB.HDF5.Sequences(hdf5)
